@@ -1,7 +1,7 @@
 package Complete::File;
 
-our $DATE = '2019-12-18'; # DATE
-our $VERSION = '0.440'; # VERSION
+our $DATE = '2021-02-02'; # DATE
+our $VERSION = '0.441'; # VERSION
 
 use 5.010001;
 use strict;
@@ -104,6 +104,9 @@ _
             schema  => 'bool',
             default => 1,
         },
+        recurse => {
+            schema => 'bool*',
+        },
     },
     result_naked => 1,
     result => {
@@ -117,6 +120,7 @@ sub complete_file {
 
     my %args   = @_;
     my $word   = $args{word} // "";
+    my $recurse = $args{recurse};
     my $handle_tilde = $args{handle_tilde} // 1;
     my $allow_dot   = $args{allow_dot} // 1;
 
@@ -261,6 +265,7 @@ sub complete_file {
         filter_func => $final_filter,
         starting_path => $starting_path,
         result_prefix => $result_prefix,
+        recurse => $recurse,
     );
 
     # XXX why doesn't Complete::Path return hash answer with path_sep? we add
@@ -301,7 +306,7 @@ Complete::File - Completion routines related to files
 
 =head1 VERSION
 
-This document describes version 0.440 of Complete::File (from Perl distribution Complete-File), released on 2019-12-18.
+This document describes version 0.441 of Complete::File (from Perl distribution Complete-File), released on 2021-02-02.
 
 =head1 DESCRIPTION
 
@@ -348,12 +353,15 @@ included.
 
 =item * B<handle_tilde> => I<bool> (default: 1)
 
+=item * B<recurse> => I<bool>
+
 =item * B<starting_path> => I<str> (default: ".")
 
 =item * B<word>* => I<str> (default: "")
 
 Word to complete.
 
+
 =back
 
 Return value:  (array)
@@ -421,12 +429,15 @@ included.
 
 =item * B<handle_tilde> => I<bool> (default: 1)
 
+=item * B<recurse> => I<bool>
+
 =item * B<starting_path> => I<str> (default: ".")
 
 =item * B<word>* => I<str> (default: "")
 
 Word to complete.
 
+
 =back
 
 Return value:  (array)
@@ -441,7 +452,7 @@ Source repository is at L<https://github.com/perlancar/perl-Complete-File>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Complete-File>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Complete-File/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -459,7 +470,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2017, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2019, 2017, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
